@@ -27,6 +27,10 @@ ICON_INFORMATION = "information"
 ICON_WARNING = "warning"
 ICON_WINLOGO = "winlogo"
 
+ICON_MODE_ICON = "icon"
+ICON_MODE_LOAD = "load"
+ICON_MODE_NONE = "none"
+
 ICONS = ("application", "asterisk", "error", "exclamation", "hand", "question", "information", "warning", "winlogo")
 
 
@@ -82,13 +86,15 @@ def download_winico():
 
 
 class DevTray(object):
-    def __init__(self, master: tkinter.Tk, text: str = "托盘图标", icon=None, menu_func=None, use_winico: bool = True, auto_install: bool = True):
+    def __init__(self, master: tkinter.Tk, text: str = "托盘图标", icon=None, icon_mode="icon", menu_func=None, use_winico: bool = True, auto_install: bool = True):
         """
         使用tcl扩展winico制作的托盘图标组件。
 
         :param master: 设置父组件。
         :param text: 设置托盘图标上的提示文本，默认是"托盘图标"。
         :param icon: 设置托盘图标上的图标图片，默认是winico的"tkchat.ico"，需要使用createfrom转换，或使用load获取图标。
+        :param icon_mode: 设置默认的图标模式，icon_mode如果是"icon"，那么将会使用createfrom来设置图标。icon_mode如果是load，
+                          将会使用load来设置图标，如果图标是icon是none，将由你自己设置图标
         :param menu_func: 设置托盘图标的事件。返回给你三个参数，event事件名，x为X坐标，y为Y坐标。
         :param use_winico: 选择是否启用自动Winico。如果取消，之后还可以使用use_winico()方法启用。
         :param auto_install: 选择是否自动下载Winico，如果未检测到主文件，将会开始下载。
@@ -107,7 +113,12 @@ class DevTray(object):
             from sys import executable
             self._icon = self.createfrom(split(executable)[0] + "\\tcl\\pkg\\tkchat.ico")
         else:
-            self._icon = icon
+            if icon_mode == "icon":
+                self._icon = self.createfrom(icon)
+            elif icon_mode == "load":
+                self._icon = self.load(icon, None)
+            elif icon_mode == "none":
+                self._icon = icon
         if menu_func is None:
             self._menu_func = self.menu
         else:
@@ -283,4 +294,5 @@ if __name__ == '__main__':
     Tray = DevTray(Window)
     Tray.icon = Tray.information()
     Tray.taskbar()
+    Window.after(1000, lambda: Tray.delete("ico#1"))
     Window.mainloop()
\ No newline at end of file
